// defining the pin mapping
#define Ypos A0
#define Xpos A1
#define Xneg A2
#define Yneg A3

// global variables
float x, y;
boolean touched;
int handshake = 0;

void setup()
{
  // start serial port at 115200 bps:
  Serial.begin(115200);
  while (!Serial) {
    ; // wait for serial port to connect. Needed for Leonardo only
  }
}

void loop() {
  // if we get a valid byte, read analog ins:
  if (Serial.available() > 0) {
    handshake = Serial.read();
    if (handshake == 57)  // Ascii code for numerical 9
      Serial.flush();
    else if (handshake == 54) { // Ascii code for 6 so serial monitor works
      touched = touch();
      if (touched) {
        x = get_loc(Xneg, Xpos, Yneg, Ypos); // call to get_loc for x position
        y = get_loc(Yneg, Ypos, Xneg, Xpos); // call to get_loc for y position
        Serial.print("X = ");
        Serial.print(x);
        Serial.print(" Y = ");
        Serial.println(y);
      } else {
        Serial.println("X = -1 Y = -1");
      }
    }
  }
}

/* touch() returns true if a touch has been detected;
returns false otherwise. You can ignore this function, 
unless you're curious. */
boolean touch()
{
  pinMode(Ypos, INPUT_PULLUP);
  pinMode(Yneg, INPUT);
  pinMode(Xneg, OUTPUT);
  pinMode(Xpos, INPUT);
  digitalWrite(Xneg, LOW);
  boolean touch = false;
  if (!digitalRead(Ypos)) {
    touch = true;
  }
  //Serial.println(touch);
  return touch;
}

/* get_loc is the heart of this program. Returns the location of the touch
along a specific axis. The axis is determined by the 4 input parameters. 
Recall, which layer do you drive and which layer do you sense to get X position?
How about Y? */
int get_loc(int pwr_neg, int pwr_pos, int sense_neg, int sense_pos) {
  pinMode(sense_neg, INPUT); // sets sense_neg to be an input pin
  pinMode(sense_pos, INPUT); // sets sense_pos to be an input pin
  digitalWrite(sense_neg, LOW); // outputs GND to sense_neg to protect from floating voltages
  pinMode(pwr_neg, OUTPUT); // sets pwr_neg to output
  digitalWrite(pwr_neg, LOW); // outputs GND to pwr_neg
  pinMode(pwr_pos, OUTPUT); // sets pwr_pos to output
  digitalWrite(pwr_pos, HIGH); // outputs +3V to pwr_pos
  return analogRead(sense_pos);
} 

